==> aws-cdk.aws-apigatewayv2-1.64.0.tar.gz: aws-cdk.aws-apigatewayv2-1.64.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-apigatewayv2",
    "version": "1.64.0",
    "description": "The CDK Construct Library for AWS::APIGatewayv2",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_apigatewayv2",
        "aws_cdk.aws_apigatewayv2._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_apigatewayv2._jsii": [
            "aws-apigatewayv2@1.64.0.jsii.tgz"
        ],
        "aws_cdk.aws_apigatewayv2": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.aws-certificatemanager==1.64.0",
        "aws-cdk.aws-iam==1.64.0",
        "aws-cdk.aws-lambda==1.64.0",
        "aws-cdk.core==1.64.0",
        "constructs>=3.0.4, <4.0.0",
        "jsii>=1.12.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved"
    ]
}
"""
)

with open("README.md") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-apigatewayv2-1.117.0.tar.gz: aws-cdk.aws-apigatewayv2-1.117.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-apigatewayv2",
    "version": "1.117.0",
    "description": "The CDK Construct Library for AWS::APIGatewayv2",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_apigatewayv2",
        "aws_cdk.aws_apigatewayv2._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_apigatewayv2._jsii": [
            "aws-apigatewayv2@1.117.0.jsii.tgz"
        ],
        "aws_cdk.aws_apigatewayv2": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.aws-certificatemanager==1.117.0",
        "aws-cdk.aws-cloudwatch==1.117.0",
        "aws-cdk.aws-ec2==1.117.0",
        "aws-cdk.aws-iam==1.117.0",
        "aws-cdk.core==1.117.0",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.31.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
